struct MessageListener {
task_source: SendableTaskSource,
context: Trusted<GlobalScope>,
}Expand description
A wrapper for glue-code between the ipc router and the event-loop.
Fields
task_source: SendableTaskSourcecontext: Trusted<GlobalScope>Implementations
Sourceimpl MessageListener
impl MessageListener
Sourcefn notify(&self, msg: MessagePortMsg)
fn notify(&self, msg: MessagePortMsg)
A new message came in, handle it via a task enqueued on the event-loop. A task is required, since we are using a trusted globalscope, and we can only access the root from the event-loop.